@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2012 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -234,25 +234,25 @@ edit_dialog (MmaidWindow *mmaid)
     {
       id3tag = mm_list_get_nth (MM_LIST (mmaid->list), i);
       if (id3tag->title && !g_list_find_custom (glist_title, id3tag->title,
-                                                        (GCompareFunc)strcmp))
+                                                    (GCompareFunc)g_strcmp))
         glist_title = g_list_insert_sorted (glist_title,
-                            g_strdup (id3tag->title), (GCompareFunc)strcmp);
+                            g_strdup (id3tag->title), (GCompareFunc)g_strcmp);
       if (id3tag->artist && !g_list_find_custom (glist_artist, id3tag->artist,
-                                                        (GCompareFunc)strcmp))
+                                                    (GCompareFunc)g_strcmp))
         glist_artist = g_list_insert_sorted (glist_artist,
-                            g_strdup (id3tag->artist), (GCompareFunc)strcmp);
+                            g_strdup (id3tag->artist), (GCompareFunc)g_strcmp);
       if (id3tag->album && !g_list_find_custom (glist_album, id3tag->album,
-                                                        (GCompareFunc)strcmp))
+                                                    (GCompareFunc)g_strcmp))
         glist_album = g_list_insert_sorted (glist_album,
-                            g_strdup (id3tag->album), (GCompareFunc)strcmp);
+                            g_strdup (id3tag->album), (GCompareFunc)g_strcmp);
       if (id3tag->comment && !g_list_find_custom (glist_comment,
-                                        id3tag->comment, (GCompareFunc)strcmp))
+                                    id3tag->comment, (GCompareFunc)g_strcmp))
         glist_comment = g_list_insert_sorted (glist_comment,
-                            g_strdup (id3tag->comment), (GCompareFunc)strcmp);
+                        g_strdup (id3tag->comment), (GCompareFunc)g_strcmp);
     }
   for (i = 0; i < 256; i++)
     if (genre[0][i] && !g_list_find_custom (glist_genre, genre[0][i],
-                                                        (GCompareFunc)strcmp))
+                                                    (GCompareFunc)g_strcmp))
       glist_genre = g_list_append (glist_genre, g_strdup (genre[0][i]));
   /* ja:選択の数を数える */
   for (i = 0; i < count; i++)
@@ -344,31 +344,31 @@ edit_dialog (MmaidWindow *mmaid)
   if (glist_title)
     {
       gtk_combo_set_popdown_strings (GTK_COMBO (combo_title), glist_title);
-      g_list_find_custom (glist_title, (GFunc)g_free, NULL);
+      g_list_foreach (glist_title, (GFunc)g_free, NULL);
       g_list_free (glist_title);
     }
   if (glist_artist)
     {
       gtk_combo_set_popdown_strings (GTK_COMBO (combo_artist), glist_artist);
-      g_list_find_custom (glist_artist, (GFunc)g_free, NULL);
+      g_list_foreach (glist_artist, (GFunc)g_free, NULL);
       g_list_free (glist_artist);
     }
   if (glist_album)
     {
       gtk_combo_set_popdown_strings (GTK_COMBO (combo_album), glist_album);
-      g_list_find_custom (glist_album, (GFunc)g_free, NULL);
+      g_list_foreach (glist_album, (GFunc)g_free, NULL);
       g_list_free (glist_album);
     }
   if (glist_comment)
     {
       gtk_combo_set_popdown_strings (GTK_COMBO (combo_comment), glist_comment);
-      g_list_find_custom (glist_comment, (GFunc)g_free, NULL);
+      g_list_foreach (glist_comment, (GFunc)g_free, NULL);
       g_list_free (glist_comment);
     }
   if (glist_genre)
     {
       gtk_combo_set_popdown_strings (GTK_COMBO (combo_genre), glist_genre);
-      g_list_find_custom (glist_genre, (GFunc)g_free, NULL);
+      g_list_foreach (glist_genre, (GFunc)g_free, NULL);
       g_list_free (glist_genre);
     }
   gtk_combo_set_value_in_list (GTK_COMBO (combo_title), FALSE, FALSE);
