@@ -33,11 +33,24 @@ G_BEGIN_DECLS
 #define MMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2012 Kazuki Iwamoto"
 
 
+#define PLAYLIST_RELATIVE 0
+#define PLAYLIST_ABSOLUTE 1
+#define PLAYLIST_BASENAME 2
+
+
+#define CODE_CRLF 0
+#define CODE_CR   1
+#define CODE_LF   2
+
+
 typedef struct _MmaidWindow
 {
   gchar *charset;               /* ja:キャラクターセット */
-  guint filekind;               /* ja:ファイルの種類 */
-  gint playlist;                /* ja:プレイリスト(0:相対,1:絶対,2:名前) */
+  guint filetype;               /* ja:ファイルの種類 */
+  gint playlist;                /* ja:プレイリスト */
+  gint separator;               /* ja:パスの区切り */
+  gint crlf;                    /* ja:改行コード */
+  gboolean header;              /* ja:ヘッダ */
   GtkWidget *list;              /* ja:描画領域 */
 } MmaidWindow;
 typedef struct _ID3Tag
@@ -74,7 +87,10 @@ extern gint genres;                     /* ja:ジャンルの数 */
 extern gint def_gnum;                   /* ja:デフォルトのジャンル */
 extern gint def_width, def_height;      /* ja:デフォルトのウインドウのサイズ */
 extern gint license;                    /* ja:ライセンス */
-extern gint playlist;                   /* ja:プレイリスト */
+extern gint def_plist;                  /* ja:プレイリスト */
+extern gint def_sep;                    /* ja:パスの区切り */
+extern gint def_crlf;                   /* ja:改行コード */
+extern gboolean def_head;               /* ja:ヘッダ */
 extern GObject *history;                /* ja:ファイルの履歴 */
 extern GdkAtom atom_id3tag;             /* ja:ID3タグ */
 extern GtkPositionType n_pos;           /* ja:ノートブックの位置 */
