@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2011 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -67,33 +67,35 @@ signal_drag_data_received (GtkWidget        *widget,
                            guint             time);
 
 
-gboolean
-signal_selection_clear (GtkWidget         *widget,
-                        GdkEventSelection *event,
-                        gpointer           user_data);
-
-
-void
-signal_selection_get (GtkWidget        *widget,
-                      GtkSelectionData *data,
-                      guint             info,
-                      guint             time,
-                      gpointer          user_data);
-
-
-void
-signal_selection_received (GtkWidget        *widget,
-                           GtkSelectionData *data,
-                           guint             time,
-                           gpointer          user_data);
-
-
 void
 signal_selection_recv (GObject   *object,
                        gchar    **argv,
                        gpointer   user_data);
 
 
+/******************************************************************************
+*                                                                             *
+* ja:シグナル/イベント関数群(クリップボード)                                  *
+*                                                                             *
+******************************************************************************/
+void
+signal_clipboard_get (GtkClipboard     *clipboard,
+                      GtkSelectionData *data,
+                      guint             info,
+                      gpointer          user_data);
+
+
+void
+signal_clipboard_clear (GtkClipboard *clipboard,
+                        gpointer      user_data);
+
+
+void
+signal_clipboard_received (GtkClipboard     *clipboard,
+                           GtkSelectionData *data,
+                           gpointer          user_data);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:シグナル/イベント関数群(メイン)                                          *
